@@ -27,7 +27,7 @@ class mapWidget(QtOpenGL.QGLWidget):
         self.width = 750
         self.height = 300
         self.setGeometry(0, 0, self.width, self.height)
-        self.graph = {'': (0, 0), 'b': (0, 1)}
+        self.graph = {'': (0, 0)}
 
     def initializeGL(self):
         print "initializeGL"
@@ -49,6 +49,7 @@ class mapWidget(QtOpenGL.QGLWidget):
 
         #paint graph
         (r, g, b) = (255, 0, 0)
+        keyPosX, keyPosY = (0, 10)
         for node in self.graph:
             color = QtGui.QColor(r, g, b)
             r = (r - 64) % 256
@@ -58,7 +59,11 @@ class mapWidget(QtOpenGL.QGLWidget):
             center = QtCore.QPointF(self.graph[node][0]*10 + self.width/2, \
                             self.graph[node][1]*10 + self.height/2)
             self.painter.drawEllipse(center, 10, 10)
-            self.painter.drawText(center, node)
+
+            self.painter.drawRect(keyPosX, keyPosY, 20, 20)
+            self.painter.drawText(keyPosX+20, keyPosY+20, node)
+            keyPosY = keyPosY+20
+
         self.painter.end()
         print "paintEvent"
 
