@@ -28,7 +28,11 @@ def ID_from_MAC(MAC):
     >>> ID_from_MAC('12:34:56:78:90:AB')
     '90AB'
     """
+
     matches = re.search("(([0-9A-F]{2}):?([0-9A-F]{2}):?){3}", MAC)
+    if matches is None:
+        print "Invalid MAC"
+        return ""
     ID = matches.group(2) + matches.group(3)
     return ID
 
@@ -76,16 +80,16 @@ def sanitize_peer_id(peer_id):
     >>> sanitize_peer_id('IllinoisNet')
     'Illi'
     >>> sanitize_peer_id('')
-    '0000'
+    '    '
     >>> sanitize_peer_id('123')
-    '1230'
+    '123 '
     """
     peer_id = str(peer_id)
     if len(peer_id) >= ID_LENGTH:
         return peer_id[:ID_LENGTH]
     else:
         while len(peer_id) < ID_LENGTH:
-            peer_id += "0"
+            peer_id += " "
     return peer_id
 
 
@@ -268,11 +272,11 @@ class WIFI_Module(Radio_Module):
             if len(self._ident)+len(k)+len(str(v)) < WIFI_MAX_IDENT_LENGTH:
                 self._ident += k+sanitize_peer_dist(v)
         try:
-            sf.run("iwconfig wlan0 essid " + self._ident)
+            sf.run("iwconfig wlan0 essid \"" + self._ident + "\"")
             print "Set Wifi ident to " + self._ident
-        except sf.RunProcessError, e:
+        except sf.RunProcessError:
             print "Wifi setESSID failed"
-            raise OSError(e)
+            raise OSError()
 
     def turnOn(self, numRetries=1):
         try:
@@ -292,6 +296,7 @@ class WIFI_Module(Radio_Module):
             self._power_state = False
         except sf.RunProcessError, e:
             if numRetries > 0:
+                time.sleep(PROCESS_RETRY_WAIT_TIME)
                 self.turnOn(numRetries = numRetries - 1)
             else:
                 print "Wifi turnOff failed"
